@@ -27,11 +27,18 @@ import org.apache.commons.vfs2.provider.http4.Http4FileNameParser;
 public class Webdav4FileNameParser extends Http4FileNameParser {
     private static final Webdav4FileNameParser INSTANCE = new Webdav4FileNameParser();
 
-    public Webdav4FileNameParser() {
-        super();
-    }
-
+    /**
+     * Gets the singleton instance.
+     *
+     * @return the singleton instance.
+     */
     public static FileNameParser getInstance() {
         return INSTANCE;
     }
+
+    /**
+     * Constructs a new instance.
+     */
+    public Webdav4FileNameParser() {
+    }
 }
